pyLBM.boundary.Neumann
======================

.. currentmodule:: pyLBM.boundary

.. autoclass:: Neumann

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Neumann.prepare_rhs
         Neumann.set_iload
         Neumann.set_rhs
         Neumann.update



   

